@@ -23,12 +23,6 @@ class DescribeCdnDomainLogsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'DescribeCdnDomainLogs')
 
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
@@ -41,20 +35,38 @@ class DescribeCdnDomainLogsRequest(RpcRequest):
 	def set_DomainName(self,DomainName):
 		self.add_query_param('DomainName',DomainName)
 
-	def get_LogDay(self):
-		return self.get_query_params().get('LogDay')
-
-	def set_LogDay(self,LogDay):
-		self.add_query_param('LogDay',LogDay)
-
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
 	def set_PageSize(self,PageSize):
 		self.add_query_param('PageSize',PageSize)
 
+	def get_EndTime(self):
+		return self.get_query_params().get('EndTime')
+
+	def set_EndTime(self,EndTime):
+		self.add_query_param('EndTime',EndTime)
+
+	def get_StartTime(self):
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self,StartTime):
+		self.add_query_param('StartTime',StartTime)
+
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
+
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
+
 	def get_PageNumber(self):
 		return self.get_query_params().get('PageNumber')
 
 	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
\ No newline at end of file
+		self.add_query_param('PageNumber',PageNumber)
+
+	def get_LogDay(self):
+		return self.get_query_params().get('LogDay')
+
+	def set_LogDay(self,LogDay):
+		self.add_query_param('LogDay',LogDay)
\ No newline at end of file
