@@ -23,11 +23,23 @@ class DescribeDomainHttpCodeDataRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'DescribeDomainHttpCodeData')
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
+	def get_LocationNameEn(self):
+		return self.get_query_params().get('LocationNameEn')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
+	def set_LocationNameEn(self,LocationNameEn):
+		self.add_query_param('LocationNameEn',LocationNameEn)
+
+	def get_StartTime(self):
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self,StartTime):
+		self.add_query_param('StartTime',StartTime)
+
+	def get_IspNameEn(self):
+		return self.get_query_params().get('IspNameEn')
+
+	def set_IspNameEn(self,IspNameEn):
+		self.add_query_param('IspNameEn',IspNameEn)
 
 	def get_TimeMerge(self):
 		return self.get_query_params().get('TimeMerge')
@@ -47,32 +59,14 @@ class DescribeDomainHttpCodeDataRequest(RpcRequest):
 	def set_EndTime(self,EndTime):
 		self.add_query_param('EndTime',EndTime)
 
-	def get_LocationNameEn(self):
-		return self.get_query_params().get('LocationNameEn')
+	def get_OwnerId(self):
+		return self.get_query_params().get('OwnerId')
 
-	def set_LocationNameEn(self,LocationNameEn):
-		self.add_query_param('LocationNameEn',LocationNameEn)
+	def set_OwnerId(self,OwnerId):
+		self.add_query_param('OwnerId',OwnerId)
 
 	def get_Interval(self):
 		return self.get_query_params().get('Interval')
 
 	def set_Interval(self,Interval):
-		self.add_query_param('Interval',Interval)
-
-	def get_StartTime(self):
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_IspNameEn(self):
-		return self.get_query_params().get('IspNameEn')
-
-	def set_IspNameEn(self,IspNameEn):
-		self.add_query_param('IspNameEn',IspNameEn)
-
-	def get_OwnerId(self):
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+		self.add_query_param('Interval',Interval)
\ No newline at end of file
