@@ -23,11 +23,29 @@ class DescribeDomainQpsDataRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'DescribeDomainQpsData')
 
-	def get_FixTimeGap(self):
-		return self.get_query_params().get('FixTimeGap')
+	def get_LocationNameEn(self):
+		return self.get_query_params().get('LocationNameEn')
 
-	def set_FixTimeGap(self,FixTimeGap):
-		self.add_query_param('FixTimeGap',FixTimeGap)
+	def set_LocationNameEn(self,LocationNameEn):
+		self.add_query_param('LocationNameEn',LocationNameEn)
+
+	def get_StartTime(self):
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self,StartTime):
+		self.add_query_param('StartTime',StartTime)
+
+	def get_IspNameEn(self):
+		return self.get_query_params().get('IspNameEn')
+
+	def set_IspNameEn(self,IspNameEn):
+		self.add_query_param('IspNameEn',IspNameEn)
+
+	def get_DomainType(self):
+		return self.get_query_params().get('DomainType')
+
+	def set_DomainType(self,DomainType):
+		self.add_query_param('DomainType',DomainType)
 
 	def get_TimeMerge(self):
 		return self.get_query_params().get('TimeMerge')
@@ -47,42 +65,12 @@ class DescribeDomainQpsDataRequest(RpcRequest):
 	def set_EndTime(self,EndTime):
 		self.add_query_param('EndTime',EndTime)
 
-	def get_LocationNameEn(self):
-		return self.get_query_params().get('LocationNameEn')
-
-	def set_LocationNameEn(self,LocationNameEn):
-		self.add_query_param('LocationNameEn',LocationNameEn)
-
-	def get_StartTime(self):
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_IspNameEn(self):
-		return self.get_query_params().get('IspNameEn')
-
-	def set_IspNameEn(self,IspNameEn):
-		self.add_query_param('IspNameEn',IspNameEn)
-
 	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
 	def set_OwnerId(self,OwnerId):
 		self.add_query_param('OwnerId',OwnerId)
 
-	def get_DomainType(self):
-		return self.get_query_params().get('DomainType')
-
-	def set_DomainType(self,DomainType):
-		self.add_query_param('DomainType',DomainType)
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_Interval(self):
 		return self.get_query_params().get('Interval')
 
