@@ -23,6 +23,12 @@ class PushObjectCacheRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'PushObjectCache')
 
+	def get_Area(self):
+		return self.get_query_params().get('Area')
+
+	def set_Area(self,Area):
+		self.add_query_param('Area',Area)
+
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
